/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rshmc8015.h"

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/

ViStatus rshmc8015_CheckStatusCallback (ViSession io);

/*****************************************************************************
 *- Common Callback Declarations --------------------------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function: rshmc8015_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rshmc8015_InitAttributes(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    // - Driver Identification
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSHMC8015_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSHMC8015_SPECIFIC_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSHMC8015_SPECIFIC_DRIVER_LOCATOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSHMC8015_SPECIFIC_DRIVER_VENDOR));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSHMC8015_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSHMC8015_CLASS_SPEC_MINOR_VERSION));

    // - Driver Capabilities
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSHMC8015_SUPPORTED_INSTRUMENT_MODELS));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSHMC8015_GROUP_CAPABILITIES));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSHMC8015_FUNCTION_CAPABILITIES));

    // - Version Info
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, RSHMC8015_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, RSHMC8015_MINOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, RSHMC8015_MINOR_MINOR_VERSION));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, RSHMC8015_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, RSHMC8015_CLASS_SPEC_MINOR_VERSION));

    checkErr(RsCore_SetSpecificDriverRevision(instrSession, RS_ATTR_SPECIFIC_DRIVER_REVISION));

Error:
    return error;
}

/*****************************************************************************
 * Function: rshmc8015_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rshmc8015_reset function calls this function. The
 *           rshmc8015_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rshmc8015_DefaultInstrSetup(ViSession instrSession)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    // Set all the attributes to the default state. Do not update inherent attributes!
    checkErr(RsCore_ApplyAttributeDefaults(instrSession, VI_FALSE));

    // Init attributes
    checkErr(rshmc8015_InitAttributes(instrSession));

    checkErr(RsCore_ResetRegistersEseSre(instrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rshmc8015_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rshmc8015_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rshmc8015_CheckStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    if (RsCore_QueryInstrStatus(instrSession) && !RsCore_Simulating(instrSession))
    {
        checkErr(RsCore_CheckStatus(instrSession, VI_SUCCESS));
    }

Error:
    return error;
}

ViStatus rshmc8015_utility_error_message(ViSession instrSession,
                                         ViStatus  errorCode,
                                         ViChar    errorMessage[])
{
    ViStatus error = VI_SUCCESS;

    (void)(RsCore_LockSession(instrSession));

    static RsCoreStringValueTable errorTable =
    {
        RSHMC8015_ERROR_CODES_AND_MSGS,
        {0, NULL}
    };

    // all VISA and RS error codes are handled as well as codes in the table
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_GetSpecificDriverStatusDesc(instrSession, errorCode, errorMessage, 256, errorTable));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/*****************************************************************************
 * Function: rshmc8015_hardwareRepCap
 * Purpose:  This function checks instance repeated capability and
 *           creates proper string.
 *****************************************************************************/
ViStatus rshmc8015_channelRepCap(ViSession instrSession,
                                 ViInt32   channel,
                                 ViChar    repCap[],
                                 ViInt32   size)
{  
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 1),
            2, "Channel");
    snprintf(repCap, size, "CH%ld", channel);

Error:
    return error;
}